@@ -1,7 +1,7 @@
 import numpy as np
 
 from pandas.compat import zip
-from pandas.core.common import isnull, _values_from_object, is_bool_dtype
+from pandas.core.common import isnull, _values_from_object, is_bool_dtype, is_list_like
 import pandas.compat as compat
 from pandas.util.decorators import Appender, deprecate_kwarg
 import re
@@ -710,6 +710,8 @@ def str_split(arr, pat=None, n=None):
     expand : bool, default False
         * If True, return DataFrame/MultiIndex expanding dimensionality.
         * If False, return Series/Index.
+
+        .. versionadded:: 0.16.1
     return_type : deprecated, use `expand`
 
     Returns
@@ -734,6 +736,35 @@ def str_split(arr, pat=None, n=None):
     return res
 
 
+def str_rsplit(arr, pat=None, n=None):
+    """
+    Split each string in the Series/Index by the given delimiter
+    string, starting at the end of the string and working to the front.
+    Equivalent to :meth:`str.rsplit`.
+
+    .. versionadded:: 0.16.2
+
+    Parameters
+    ----------
+    pat : string, default None
+        Separator to split on. If None, splits on whitespace
+    n : int, default -1 (all)
+        None, 0 and -1 will be interpreted as return all splits
+    expand : bool, default False
+        * If True, return DataFrame/MultiIndex expanding dimensionality.
+        * If False, return Series/Index.
+
+    Returns
+    -------
+    split : Series/Index or DataFrame/MultiIndex of objects
+    """
+    if n is None or n == 0:
+        n = -1
+    f = lambda x: x.rsplit(pat, n)
+    res = _na_map(f, arr)
+    return res
+
+
 def str_slice(arr, start=None, stop=None, step=None):
     """
     Slice substrings from each element in the Series/Index
@@ -813,7 +844,7 @@ def str_strip(arr, to_strip=None, side='both'):
 
 
 def str_wrap(arr, width, **kwargs):
-    """
+    r"""
     Wrap long strings in the Series/Index to be formatted in
     paragraphs with length less than a given width.
 
@@ -1090,7 +1121,11 @@ class StringMethods(object):
         else:
             index = self.series.index
             if expand:
-                cons_row = self.series._constructor
+                def cons_row(x):
+                    if is_list_like(x):
+                        return x
+                    else:
+                        return [ x ]
                 cons = self.series._constructor_expanddim
                 data = [cons_row(x) for x in result]
                 return cons(data, index=index)
@@ -1111,6 +1146,11 @@ class StringMethods(object):
         result = str_split(self.series, pat, n=n)
         return self._wrap_result_expand(result, expand=expand)
 
+    @copy(str_rsplit)
+    def rsplit(self, pat=None, n=-1, expand=False):
+        result = str_rsplit(self.series, pat, n=n)
+        return self._wrap_result_expand(result, expand=expand)
+
     _shared_docs['str_partition'] = ("""
     Split the string at the %(side)s occurrence of `sep`, and return 3 elements
     containing the part before the separator, the separator itself,
