@@ -53,19 +53,6 @@ class TestPivotTable(tm.TestCase):
         expected = self.data.groupby(index + [columns])['D'].agg(np.mean).unstack()
         tm.assert_frame_equal(table, expected)
 
-    def test_pivot_table_warnings(self):
-        index = ['A', 'B']
-        columns = 'C'
-        with tm.assert_produces_warning(FutureWarning):
-            table = pivot_table(self.data, values='D', rows=index,
-                                cols=columns)
-
-        with tm.assert_produces_warning(False):
-            table2 = pivot_table(self.data, values='D', index=index,
-                                 columns=columns)
-
-        tm.assert_frame_equal(table, table2)
-
     def test_pivot_table_nocols(self):
         df = DataFrame({'rows': ['a', 'b', 'c'],
                         'cols': ['x', 'y', 'z'],
@@ -173,13 +160,31 @@ class TestPivotTable(tm.TestCase):
     def test_pivot_index_with_nan(self):
         # GH 3588
         nan = np.nan
-        df = DataFrame({"a":['R1', 'R2', nan, 'R4'], 'b':["C1", "C2", "C3" , "C4"], "c":[10, 15, nan , 20]})
+        df = DataFrame({'a':['R1', 'R2', nan, 'R4'],
+                        'b':['C1', 'C2', 'C3' , 'C4'],
+                        'c':[10, 15, 17, 20]})
         result = df.pivot('a','b','c')
-        expected = DataFrame([[nan,nan,nan,nan],[nan,10,nan,nan],
-                              [nan,nan,nan,nan],[nan,nan,15,20]],
-                             index = Index(['R1','R2',nan,'R4'],name='a'),
-                             columns = Index(['C1','C2','C3','C4'],name='b'))
+        expected = DataFrame([[nan,nan,17,nan],[10,nan,nan,nan],
+                              [nan,15,nan,nan],[nan,nan,nan,20]],
+                             index = Index([nan,'R1','R2','R4'], name='a'),
+                             columns = Index(['C1','C2','C3','C4'], name='b'))
         tm.assert_frame_equal(result, expected)
+        tm.assert_frame_equal(df.pivot('b', 'a', 'c'), expected.T)
+
+        # GH9491
+        df = DataFrame({'a':pd.date_range('2014-02-01', periods=6, freq='D'),
+                        'c':100 + np.arange(6)})
+        df['b'] = df['a'] - pd.Timestamp('2014-02-02')
+        df.loc[1, 'a'] = df.loc[3, 'a'] = nan
+        df.loc[1, 'b'] = df.loc[4, 'b'] = nan
+
+        pv = df.pivot('a', 'b', 'c')
+        self.assertEqual(pv.notnull().values.sum(), len(df))
+
+        for _, row in df.iterrows():
+            self.assertEqual(pv.loc[row['a'], row['b']], row['c'])
+
+        tm.assert_frame_equal(df.pivot('b', 'a', 'c'), pv.T)
 
     def test_pivot_with_tz(self):
         # GH 5878
@@ -222,12 +227,14 @@ class TestPivotTable(tm.TestCase):
         def _check_output(res, col, index=['A', 'B'], columns=['C']):
             cmarg = res['All'][:-1]
             exp = self.data.groupby(index)[col].mean()
-            tm.assert_series_equal(cmarg, exp)
+            tm.assert_series_equal(cmarg, exp, check_names=False)
+            self.assertEqual(cmarg.name, 'All')
 
             res = res.sortlevel()
             rmarg = res.xs(('All', ''))[:-1]
             exp = self.data.groupby(columns)[col].mean()
-            tm.assert_series_equal(rmarg, exp)
+            tm.assert_series_equal(rmarg, exp, check_names=False)
+            self.assertEqual(rmarg.name, ('All', ''))
 
             gmarg = res['All']['All', '']
             exp = self.data[col].mean()
@@ -268,12 +275,12 @@ class TestPivotTable(tm.TestCase):
 
         # issue number #8349: pivot_table with margins and dictionary aggfunc
 
-        df=DataFrame([  {'JOB':'Worker','NAME':'Bob' ,'YEAR':2013,'MONTH':12,'DAYS': 3,'SALARY': 17}, 
-                        {'JOB':'Employ','NAME':'Mary','YEAR':2013,'MONTH':12,'DAYS': 5,'SALARY': 23}, 
-                        {'JOB':'Worker','NAME':'Bob' ,'YEAR':2014,'MONTH': 1,'DAYS':10,'SALARY':100}, 
-                        {'JOB':'Worker','NAME':'Bob' ,'YEAR':2014,'MONTH': 1,'DAYS':11,'SALARY':110}, 
-                        {'JOB':'Employ','NAME':'Mary','YEAR':2014,'MONTH': 1,'DAYS':15,'SALARY':200}, 
-                        {'JOB':'Worker','NAME':'Bob' ,'YEAR':2014,'MONTH': 2,'DAYS': 8,'SALARY': 80}, 
+        df=DataFrame([  {'JOB':'Worker','NAME':'Bob' ,'YEAR':2013,'MONTH':12,'DAYS': 3,'SALARY': 17},
+                        {'JOB':'Employ','NAME':'Mary','YEAR':2013,'MONTH':12,'DAYS': 5,'SALARY': 23},
+                        {'JOB':'Worker','NAME':'Bob' ,'YEAR':2014,'MONTH': 1,'DAYS':10,'SALARY':100},
+                        {'JOB':'Worker','NAME':'Bob' ,'YEAR':2014,'MONTH': 1,'DAYS':11,'SALARY':110},
+                        {'JOB':'Employ','NAME':'Mary','YEAR':2014,'MONTH': 1,'DAYS':15,'SALARY':200},
+                        {'JOB':'Worker','NAME':'Bob' ,'YEAR':2014,'MONTH': 2,'DAYS': 8,'SALARY': 80},
                         {'JOB':'Employ','NAME':'Mary','YEAR':2014,'MONTH': 2,'DAYS': 5,'SALARY':190} ])
 
         df=df.set_index(['JOB','NAME','YEAR','MONTH'],drop=False,append=False)
@@ -674,12 +681,14 @@ class TestCrosstab(tm.TestCase):
         all_cols = result['All', '']
         exp_cols = df.groupby(['a']).size().astype('i8')
         exp_cols = exp_cols.append(Series([len(df)], index=['All']))
+        exp_cols.name = ('All', '')
 
         tm.assert_series_equal(all_cols, exp_cols)
 
         all_rows = result.ix['All']
         exp_rows = df.groupby(['b', 'c']).size().astype('i8')
         exp_rows = exp_rows.append(Series([len(df)], index=[('All', '')]))
+        exp_rows.name = 'All'
 
         exp_rows = exp_rows.reindex(all_rows.index)
         exp_rows = exp_rows.fillna(0).astype(np.int64)
