@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime,timedelta
 from pandas.compat import range, long, zip
 from pandas import compat
 import re
@@ -12,6 +12,8 @@ import pandas.tseries.offsets as offsets
 import pandas.core.common as com
 import pandas.lib as lib
 import pandas.tslib as tslib
+import pandas._period as period
+from pandas.tslib import Timedelta
 
 class FreqGroup(object):
     FR_ANN = 1000
@@ -30,12 +32,12 @@ class FreqGroup(object):
 
 class Resolution(object):
 
-    RESO_US = tslib.US_RESO
-    RESO_MS = tslib.MS_RESO
-    RESO_SEC = tslib.S_RESO
-    RESO_MIN = tslib.T_RESO
-    RESO_HR = tslib.H_RESO
-    RESO_DAY = tslib.D_RESO
+    RESO_US = period.US_RESO
+    RESO_MS = period.MS_RESO
+    RESO_SEC = period.S_RESO
+    RESO_MIN = period.T_RESO
+    RESO_HR = period.H_RESO
+    RESO_DAY = period.D_RESO
 
     _reso_str_map = {
     RESO_US: 'microsecond',
@@ -45,7 +47,9 @@ class Resolution(object):
     RESO_HR: 'hour',
     RESO_DAY: 'day'}
 
-    _reso_period_map = {
+    _str_reso_map = dict([(v, k) for k, v in compat.iteritems(_reso_str_map)])
+
+    _reso_freq_map = {
     'year': 'A',
     'quarter': 'Q',
     'month': 'M',
@@ -57,13 +61,28 @@ class Resolution(object):
     'microsecond': 'U',
     'nanosecond': 'N'}
 
+    _freq_reso_map = dict([(v, k) for k, v in compat.iteritems(_reso_freq_map)])
+
     @classmethod
     def get_str(cls, reso):
         return cls._reso_str_map.get(reso, 'day')
 
+    @classmethod
+    def get_reso(cls, resostr):
+        return cls._str_reso_map.get(resostr, cls.RESO_DAY)
+
     @classmethod
     def get_freq(cls, resostr):
-        return cls._reso_period_map[resostr]
+        return cls._reso_freq_map[resostr]
+
+    @classmethod
+    def get_str_from_freq(cls, freq):
+        return cls._freq_reso_map.get(freq, 'day')
+
+    @classmethod
+    def get_reso_from_freq(cls, freq):
+        return cls.get_reso(cls.get_str_from_freq(freq))
+
 
 def get_reso_string(reso):
     return Resolution.get_str(reso)
@@ -259,9 +278,18 @@ for _i, _weekday in enumerate(['MON', 'TUE', 'WED', 'THU', 'FRI']):
 _legacy_reverse_map = dict((v, k) for k, v in
                            reversed(sorted(compat.iteritems(_rule_aliases))))
 
+_name_to_offset_map = {'days': Day(1),
+                       'hours': Hour(1),
+                       'minutes': Minute(1),
+                       'seconds': Second(1),
+                       'milliseconds': Milli(1),
+                       'microseconds': Micro(1),
+                       'nanoseconds': Nano(1)}
+
 def to_offset(freqstr):
     """
-    Return DateOffset object from string representation
+    Return DateOffset object from string representation or
+    Timedelta object
 
     Examples
     --------
@@ -281,6 +309,23 @@ def to_offset(freqstr):
             name, stride = stride, name
         name, _ = _base_and_stride(name)
         delta = get_offset(name) * stride
+
+    elif isinstance(freqstr, timedelta):
+        delta = None
+        freqstr = Timedelta(freqstr)
+        try:
+            for name in freqstr.components._fields:
+                offset = _name_to_offset_map[name]
+                stride = getattr(freqstr.components, name)
+                if stride != 0:
+                    offset = stride * offset
+                    if delta is None:
+                        delta = offset
+                    else:
+                        delta = delta + offset
+        except Exception:
+            raise ValueError("Could not evaluate %s" % freqstr)
+
     else:
         delta = None
         stride_sign = None
@@ -593,7 +638,7 @@ def _period_alias_dictionary():
 
 
 def _infer_period_group(freqstr):
-    return _period_group(Resolution._reso_period_map[freqstr])
+    return _period_group(Resolution._reso_freq_map[freqstr])
 
 
 def _period_group(freqstr):
@@ -626,11 +671,11 @@ def _period_str_to_code(freqstr):
 def infer_freq(index, warn=True):
     """
     Infer the most likely frequency given the input index. If the frequency is
-    uncertain, a warning will be printed
+    uncertain, a warning will be printed. 
 
     Parameters
     ----------
-    index : DatetimeIndex
+    index : DatetimeIndex or TimedeltaIndex
             if passed a Series will use the values of the series (NOT THE INDEX)
     warn : boolean, default True
 
@@ -639,17 +684,23 @@ def infer_freq(index, warn=True):
     freq : string or None
         None if no discernible frequency
         TypeError if the index is not datetime-like
+        ValueError if there are less than three values.
     """
     import pandas as pd
 
     if isinstance(index, com.ABCSeries):
         values = index.values
-        if not (com.is_datetime64_dtype(index.values) or values.dtype == object):
+        if not (com.is_datetime64_dtype(index.values) or com.is_timedelta64_dtype(index.values) or values.dtype == object):
             raise TypeError("cannot infer freq from a non-convertible dtype on a Series of {0}".format(index.dtype))
         index = values
-    if isinstance(index, pd.PeriodIndex):
+
+    if com.is_period_arraylike(index):
         raise TypeError("PeriodIndex given. Check the `freq` attribute "
-                         "instead of using infer_freq.")
+                        "instead of using infer_freq.")
+    elif isinstance(index, pd.TimedeltaIndex):
+        inferer = _TimedeltaFrequencyInferer(index, warn=warn)
+        return inferer.get_freq()
+
     if isinstance(index, pd.Index) and not isinstance(index, pd.DatetimeIndex):
         if isinstance(index, (pd.Int64Index, pd.Float64Index)):
             raise TypeError("cannot infer freq from a non-convertible index type {0}".format(type(index)))
@@ -666,25 +717,6 @@ _ONE_MINUTE = 60 * _ONE_SECOND
 _ONE_HOUR = 60 * _ONE_MINUTE
 _ONE_DAY = 24 * _ONE_HOUR
 
-def _tz_convert_with_transitions(values, to_tz, from_tz):
-    """
-    convert i8 values from the specificed timezone to the to_tz zone, taking
-    into account DST transitions
-    """
-
-    # vectorization is slow, so tests if we can do this via the faster tz_convert
-    f = lambda x: tslib.tz_convert_single(x, to_tz, from_tz)
-
-    if len(values) > 2:
-        first_slow, last_slow = f(values[0]),f(values[-1])
-
-        first_fast, last_fast = tslib.tz_convert(np.array([values[0],values[-1]],dtype='i8'),to_tz,from_tz)
-
-        # don't cross a DST, so ok
-        if first_fast == first_slow and last_fast == last_slow:
-            return tslib.tz_convert(values,to_tz,from_tz)
-
-    return np.vectorize(f)(values)
 
 class _FrequencyInferer(object):
     """
@@ -695,8 +727,11 @@ class _FrequencyInferer(object):
         self.index = index
         self.values = np.asarray(index).view('i8')
 
-        if index.tz is not None:
-            self.values = _tz_convert_with_transitions(self.values,'UTC',index.tz)
+        # This moves the values, which are implicitly in UTC, to the
+        # the timezone so they are in local time
+        if hasattr(index,'tz'):
+            if index.tz is not None:
+                self.values = tslib.tz_convert(self.values, 'UTC', index.tz)
 
         self.warn = warn
 
@@ -709,10 +744,18 @@ class _FrequencyInferer(object):
     def deltas(self):
         return tslib.unique_deltas(self.values)
 
+    @cache_readonly
+    def deltas_asi8(self):
+        return tslib.unique_deltas(self.index.asi8)
+
     @cache_readonly
     def is_unique(self):
         return len(self.deltas) == 1
 
+    @cache_readonly
+    def is_unique_asi8(self):
+        return len(self.deltas_asi8) == 1
+
     def get_freq(self):
         if not self.is_monotonic or not self.index.is_unique:
             return None
@@ -721,9 +764,15 @@ class _FrequencyInferer(object):
         if _is_multiple(delta, _ONE_DAY):
             return self._infer_daily_rule()
         else:
-            # Possibly intraday frequency
-            if not self.is_unique:
+            # Business hourly, maybe. 17: one day / 65: one weekend
+            if self.hour_deltas in ([1, 17], [1, 65], [1, 17, 65]):
+                return 'BH'
+            # Possibly intraday frequency.  Here we use the
+            # original .asi8 values as the modified values
+            # will not work around DST transitions.  See #8772
+            elif not self.is_unique_asi8:
                 return None
+            delta = self.deltas_asi8[0]
             if _is_multiple(delta, _ONE_HOUR):
                 # Hours
                 return _maybe_add_count('H', delta / _ONE_HOUR)
@@ -747,6 +796,10 @@ class _FrequencyInferer(object):
     def day_deltas(self):
         return [x / _ONE_DAY for x in self.deltas]
 
+    @cache_readonly
+    def hour_deltas(self):
+        return [x / _ONE_HOUR for x in self.deltas]
+
     @cache_readonly
     def fields(self):
         return tslib.build_field_sarray(self.values)
@@ -882,7 +935,9 @@ class _FrequencyInferer(object):
             return None
 
         week_of_months = unique((self.index.day - 1) // 7)
-        if len(week_of_months) > 1:
+        # Only attempt to infer up to WOM-4. See #9425
+        week_of_months = week_of_months[week_of_months < 4]
+        if len(week_of_months) == 0 or len(week_of_months) > 1:
             return None
 
         # get which week
@@ -893,6 +948,18 @@ class _FrequencyInferer(object):
 
 import pandas.core.algorithms as algos
 
+class _TimedeltaFrequencyInferer(_FrequencyInferer):
+
+    def _infer_daily_rule(self):
+        if self.is_unique:
+            days = self.deltas[0] / _ONE_DAY
+            if days % 7 == 0:
+                # Weekly
+                alias = _weekday_rule_aliases[self.rep_stamp.weekday()]
+                return _maybe_add_count('W-%s' % alias, days / 7)
+            else:
+                return _maybe_add_count('D', days)
+
 
 def _maybe_add_count(base, count):
     if count > 1:
@@ -929,25 +996,31 @@ def is_subperiod(source, target):
         if _is_quarterly(source):
             return _quarter_months_conform(_get_rule_month(source),
                                            _get_rule_month(target))
-        return source in ['D', 'C', 'B', 'M', 'H', 'T', 'S']
+        return source in ['D', 'C', 'B', 'M', 'H', 'T', 'S', 'L', 'U', 'N']
     elif _is_quarterly(target):
-        return source in ['D', 'C', 'B', 'M', 'H', 'T', 'S']
-    elif target == 'M':
-        return source in ['D', 'C', 'B', 'H', 'T', 'S']
+        return source in ['D', 'C', 'B', 'M', 'H', 'T', 'S', 'L', 'U', 'N']
+    elif _is_monthly(target):
+        return source in ['D', 'C', 'B', 'H', 'T', 'S', 'L', 'U', 'N']
     elif _is_weekly(target):
-        return source in [target, 'D', 'C', 'B', 'H', 'T', 'S']
+        return source in [target, 'D', 'C', 'B', 'H', 'T', 'S', 'L', 'U', 'N']
     elif target == 'B':
-        return source in ['B', 'H', 'T', 'S']
+        return source in ['B', 'H', 'T', 'S', 'L', 'U', 'N']
     elif target == 'C':
-        return source in ['C', 'H', 'T', 'S']
+        return source in ['C', 'H', 'T', 'S', 'L', 'U', 'N']
     elif target == 'D':
-        return source in ['D', 'H', 'T', 'S']
+        return source in ['D', 'H', 'T', 'S', 'L', 'U', 'N']
     elif target == 'H':
-        return source in ['H', 'T', 'S']
+        return source in ['H', 'T', 'S', 'L', 'U', 'N']
     elif target == 'T':
-        return source in ['T', 'S']
+        return source in ['T', 'S', 'L', 'U', 'N']
     elif target == 'S':
-        return source in ['S']
+        return source in ['S', 'L', 'U', 'N']
+    elif target == 'L':
+        return source in ['L', 'U', 'N']
+    elif target == 'U':
+        return source in ['U', 'N']
+    elif target == 'N':
+        return source in ['N']
 
 
 def is_superperiod(source, target):
@@ -982,25 +1055,31 @@ def is_superperiod(source, target):
             smonth = _get_rule_month(source)
             tmonth = _get_rule_month(target)
             return _quarter_months_conform(smonth, tmonth)
-        return target in ['D', 'C', 'B', 'M', 'H', 'T', 'S']
+        return target in ['D', 'C', 'B', 'M', 'H', 'T', 'S', 'L', 'U', 'N']
     elif _is_quarterly(source):
-        return target in ['D', 'C', 'B', 'M', 'H', 'T', 'S']
-    elif source == 'M':
-        return target in ['D', 'C', 'B', 'H', 'T', 'S']
+        return target in ['D', 'C', 'B', 'M', 'H', 'T', 'S', 'L', 'U', 'N']
+    elif _is_monthly(source):
+        return target in ['D', 'C', 'B', 'H', 'T', 'S', 'L', 'U', 'N']
     elif _is_weekly(source):
-        return target in [source, 'D', 'C', 'B', 'H', 'T', 'S']
+        return target in [source, 'D', 'C', 'B', 'H', 'T', 'S', 'L', 'U', 'N']
     elif source == 'B':
-        return target in ['D', 'C', 'B', 'H', 'T', 'S']
+        return target in ['D', 'C', 'B', 'H', 'T', 'S', 'L', 'U', 'N']
     elif source == 'C':
-        return target in ['D', 'C', 'B', 'H', 'T', 'S']
+        return target in ['D', 'C', 'B', 'H', 'T', 'S', 'L', 'U', 'N']
     elif source == 'D':
-        return target in ['D', 'C', 'B', 'H', 'T', 'S']
+        return target in ['D', 'C', 'B', 'H', 'T', 'S', 'L', 'U', 'N']
     elif source == 'H':
-        return target in ['H', 'T', 'S']
+        return target in ['H', 'T', 'S', 'L', 'U', 'N']
     elif source == 'T':
-        return target in ['T', 'S']
+        return target in ['T', 'S', 'L', 'U', 'N']
     elif source == 'S':
-        return target in ['S']
+        return target in ['S', 'L', 'U', 'N']
+    elif source == 'L':
+        return target in ['L', 'U', 'N']
+    elif source == 'U':
+        return target in ['U', 'N']
+    elif source == 'N':
+        return target in ['N']
 
 
 def _get_rule_month(source, default='DEC'):
@@ -1024,7 +1103,12 @@ def _quarter_months_conform(source, target):
 
 def _is_quarterly(rule):
     rule = rule.upper()
-    return rule == 'Q' or rule.startswith('Q-')
+    return rule == 'Q' or rule.startswith('Q-') or rule.startswith('BQ')
+
+
+def _is_monthly(rule):
+    rule = rule.upper()
+    return rule == 'M' or rule == 'BM'
 
 
 def _is_weekly(rule):
